@@ -351,8 +351,11 @@ static char cmd[] =
 "if {$cmds ne \"\"} {\n"
 "foreach cmd $cmds {\n"
 "foreach {op def} $cmd break\n"
-"if {[lindex $def 0] eq $origin} {\n"
+"set domain [lindex $def 0]\n"
+"if {$domain eq $origin} {\n"
 "set def [concat $dest [lrange $def 1 end]]}\n"
+"if {[my isobject $domain] && [$domain istype ::xotcl::Slot]} {\n"
+"continue}\n"
 "$dest trace add variable $var $op $def}}}}\n"
 "set origin [lindex [::xotcl::my set targetList] 0]\n"
 "if {[::xotcl::my isclass $origin]} {\n"
