@@ -7,11 +7,6 @@
  * core routines
  */
 
-#ifndef lint
-static char rcsid[] = "$Id: sdbm.c,v 1.1 2004/05/23 22:50:39 neumann Exp $";
-#endif
-
-/*#include "config.h"*/
 #include "sdbm.h"
 #include "tune.h"
 #include "pair.h"
